@@ -67,7 +67,7 @@ use Coro::AnyEvent ();
 
 use base Exporter::;
 
-our $VERSION = 6.52;
+our $VERSION = 6.53;
 our @EXPORT_OK = "select";
 
 sub import {
@@ -79,7 +79,7 @@ sub import {
    }
 }
 
-sub select(;*$$$) { # not the correct prototype, but well... :()
+sub select {
    if (@_ == 0) {
       return CORE::select
    } elsif (@_ == 1) {
